@@ -1,7 +1,7 @@
 import datetime
 from dataclasses import dataclass, field
 
-from flanautils import FlanaBase, MongoBase
+from flanautils import DCMongoBase, FlanaBase
 
 from multibot.models.chat import Chat
 from multibot.models.database import db
@@ -11,7 +11,7 @@ from multibot.models.user import User
 
 
 @dataclass(eq=False)
-class BotAction(MongoBase, FlanaBase):
+class BotAction(DCMongoBase, FlanaBase):
     collection = db.bot_action
     _unique_keys = 'message'
     _nullable_unique_keys = 'message'
